@@ -87,7 +87,15 @@ LanguageSupport::~LanguageSupport()
 
 KDevelop::ParseJob *LanguageSupport::createParseJob(const IndexedString &url)
 {
-    return new ParseJob(url, this);
+    auto *job = new ParseJob(url, this);
+
+    // bypass the 5 MB maximum file size limit for the internal file
+    if (url == internalFunctionFile()) {
+        job->setMaximumFileSize(std::numeric_limits<qint64>::max());
+        job->setMinimumFeatures(TopDUContext::AllDeclarationsAndContexts);
+    }
+
+    return job;
 }
 
 QString LanguageSupport::name() const
@@ -161,15 +169,15 @@ bool isMagicConstant(QPair<QString, Range> word) {
     return false;
 }
 
-QWidget* LanguageSupport::specialLanguageObjectNavigationWidget(const QUrl& url, const Cursor& position)
+QPair<QWidget*, Range> LanguageSupport::specialLanguageObjectNavigationWidget(const QUrl& url, const Cursor& position)
 {
     QPair<QString, Range> word = wordUnderCursor(url, position);
     if ( isMagicConstant(word) ) {
         DUChainReadLocker lock;
         if (TopDUContext* top = standardContext(url)) {
-            return new NavigationWidget(TopDUContextPointer(top), position, word.first);
+            return {new NavigationWidget(TopDUContextPointer(top), position, word.first), word.second};
         } else {
-            return nullptr;
+            return {nullptr, Range::invalid()};
         }
     }
     return ILanguageSupport::specialLanguageObjectNavigationWidget(url, position);
